# Bionty: Manage biological entities

Never worry again whether a gene, a protein, a system, a perturbagen, etc. in a piece of data is in fact the thing you think it is!

- An unambiguous intuitive API for interacting with biological entities, based on scientific community standards.
- A reference for making data science workflows and data stores a lot more robust, for instance, using [lamindb](https://lamin.ai/lamindb).
- Directly standardize `DataFrame` and `AnnData` objects and their on-disk representations against entities.
- Enable collaborative & machine learning at scale through employing a universal programmatic standard.

---

Install via

```
pip install bionty
```

Get started by browsing a [quickstart](guides/quickstart) that walks you through interacting with genes, proteins, and taxons (species).

For more information:

- Check out the [guides](guides/index).
- Browse the full [API reference](api).

```{toctree}
:maxdepth: 1
:hidden:

tasks/index
guides/index
api
changelog
```
